#' Trim something other than whitespace
#'
#' See [strex::str_trim_anything()].
#'
#' @inheritParams strex::str_trim_anything
#'
#' @export
trim_anything <- strex::str_trim_anything

#' @rdname trim_anything
#' @export
str_trim_anything <- trim_anything
